function [axc1, axc2, axc3, Lx] = AsympCorrelationDWPTFBM(alpha,Wlevel1,Wlevel2,Wreg1,Wreg2,NbITER)
%%        INPUTS
% alpha:    Parameter for the 1/f^alpha noise.
% Wlevel1: Wavelet Packet Analysis at level ``Wlevel1''.
% Wlevel2: Wavelet Packet Analysis at level ``Wlevel2''.
% Wreg1:   Wavelet Packet filtering with regularity (order) ``Wreg1''.  
% Wreg2:   Wavelet Packet filtering with regularity (order) ``Wreg2''.
% NbITER:  Number of iterations.
% pas:     Number of bins per output histogram. 
% 
%%        OUTPUTS
% axc1: Average of Normalized Autocorrelation functions associated with  
%       the DWPT subbands at level ``Wlevel1'' with regularity ``Wreg1''.
% axc2: Average of Normalized Autocorrelation functions associated with  
%       the DWPT subbands at level ``Wlevel2'' with regularity ``Wreg1''.
% axc3: Average of Normalized Autocorrelation functions associated with  
%       the DWPT subbands at level ``Wlevel2'' with regularity ``Wreg2''.
% axc1, axc2, axc3 are 4 *Lx matrices (4 test paths are considered).
% Lx:   Length per Autocorrelation Function.
%%
Ndata=2^20;
%%
% Frequency Response of AR(1) filter
if (alpha <=0 || alpha>=3)
    error('Requires 0 < alpha < 3 .');
end
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Retrieve usefull lengths
testsig=zeros(1,Ndata);
WT1=wpdec(testsig,Wlevel1,Wreg1);
WT2=wpdec(testsig,Wlevel2,Wreg1);
WT3=wpdec(testsig,Wlevel2,Wreg2);
Lxc1=length(xcorr(wpcoef(WT1,[Wlevel1 0]),'coeff'));
Lxc2=length(xcorr(wpcoef(WT2,[Wlevel2 0]),'coeff'));
Lxc3=length(xcorr(wpcoef(WT3,[Wlevel2 0]),'coeff'));
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pas=25;
Lx=2*pas+1;
axc1=zeros(4,Lx);
axc2=zeros(4,Lx);
axc3=zeros(4,Lx);
%%
h = waitbar(0,'Please wait, computing ...');
for ITER=1:NbITER
    % Correlated random process
    sig=powernoise(alpha,Ndata);
    sig=sig';
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%  ANALYSIS AT Wlevel1 WITH Wreg1
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    WTree3=wpdec(sig,Wlevel1,Wreg1);
    %%
    Yjk=wpcoef(WTree3,[Wlevel1 0]);
    Djk = xcorr(Yjk,'coeff');
    axc1(1,:)=axc1(1,:)+Djk((Lxc1+1)/2-(Lx-1)/2:1:(Lxc1+1)/2+(Lx-1)/2);
    %%
    Yjk=wpcoef(WTree3,[Wlevel1 2^(Wlevel1-3)]);
    Djk = xcorr(Yjk,'coeff');
    axc1(2,:)=axc1(2,:)+Djk((Lxc1+1)/2-(Lx-1)/2:1:(Lxc1+1)/2+(Lx-1)/2);
    %%
    Yjk=wpcoef(WTree3,[Wlevel1 2^(Wlevel1-2)]);
    Djk = xcorr(Yjk,'coeff');
    axc1(3,:)=axc1(3,:)+Djk((Lxc1+1)/2-(Lx-1)/2:1:(Lxc1+1)/2+(Lx-1)/2);
    %%
    Yjk=wpcoef(WTree3,[Wlevel1 2^(Wlevel1-1)]);
    Djk = xcorr(Yjk,'coeff');
    axc1(4,:)=axc1(4,:)+Djk((Lxc1+1)/2-(Lx-1)/2:1:(Lxc1+1)/2+(Lx-1)/2);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % ANALYSIS AT Wlevel2 WITH Wreg1
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    WTree3=wpdec(sig,Wlevel2,Wreg1);
    %%
    Zjk=wpcoef(WTree3,[Wlevel2 0]);
    Fjk = xcorr(Zjk,'coeff');
    axc2(1,:)=axc2(1,:)+Fjk((Lxc2+1)/2-(Lx-1)/2:1:(Lxc2+1)/2+(Lx-1)/2);
    %%
    Zjk=wpcoef(WTree3,[Wlevel2 2^(Wlevel2-3)]);
    Fjk = xcorr(Zjk,'coeff');
    axc2(2,:)=axc2(2,:)+Fjk((Lxc2+1)/2-(Lx-1)/2:1:(Lxc2+1)/2+(Lx-1)/2);
    %%
    Zjk=wpcoef(WTree3,[Wlevel2 2^(Wlevel2-2)]);
    Fjk = xcorr(Zjk,'coeff');
    axc2(3,:)=axc2(3,:)+Fjk((Lxc2+1)/2-(Lx-1)/2:1:(Lxc2+1)/2+(Lx-1)/2);
    %%
    Zjk=wpcoef(WTree3,[Wlevel2 2^(Wlevel2-1)]);
    Fjk = xcorr(Zjk,'coeff');
    axc2(4,:)=axc2(4,:)+Fjk((Lxc2+1)/2-(Lx-1)/2:1:(Lxc2+1)/2+(Lx-1)/2);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % ANALYSIS AT Wlevel2 WITH Wreg2
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    WTree3=wpdec(sig,Wlevel2,Wreg2);
    %%
    Ujk=wpcoef(WTree3,[Wlevel2 0]);
    Gjk = xcorr(Ujk,'coeff');
    axc3(1,:)=axc3(1,:)+Gjk((Lxc3+1)/2-(Lx-1)/2:1:(Lxc3+1)/2+(Lx-1)/2);
    %%
    Ujk=wpcoef(WTree3,[Wlevel2 2^(Wlevel2-3)]);
    Gjk = xcorr(Ujk,'coeff');
    axc3(2,:)=axc3(2,:)+Gjk((Lxc3+1)/2-(Lx-1)/2:1:(Lxc3+1)/2+(Lx-1)/2);
    %%
    Ujk=wpcoef(WTree3,[Wlevel2 2^(Wlevel2-2)]);
    Gjk = xcorr(Ujk,'coeff');
    axc3(3,:)=axc3(3,:)+Gjk((Lxc3+1)/2-(Lx-1)/2:1:(Lxc3+1)/2+(Lx-1)/2);
    %%
    Ujk=wpcoef(WTree3,[Wlevel2 2^(Wlevel2-1)]);
    Gjk = xcorr(Ujk,'coeff');
    axc3(4,:)=axc3(4,:)+Gjk((Lxc3+1)/2-(Lx-1)/2:1:(Lxc3+1)/2+(Lx-1)/2);
    waitbar(ITER/NbITER,h)
end
close(h)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
axc1=axc1./NbITER;
axc2=axc2./NbITER;
axc3=axc3./NbITER;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright: am.atto@telecom-bretagne.eu
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%