%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Demo for paper {Wavelet Packets of fractional Brownian motion: 
% Asymptotic Analysis and Spectrum Estimation}, by
% {A. M. Atto and D. Pastor and G. Mercier}, {IEEE trans IT} {2009}.
% This demo concerns the "AutoCorrelation Analysis" in DWPT paths.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The autocorrelation function of the DWPT coefficients is denoted 
% by R_{j,n_a(j)), with
% n_0(j) = 0;
% n_{\pi/4}(j) = 2^{j-3};
% n_{\pi/2}(j) = 2^{j-2};
% n_{\pi}(j) = 2^{j-1};
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all;
close all;
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set parameters : Default = Values used in the paper.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Wlevel1=3; % First DWPT level for the analysis
Wlevel2=6; % Second DWPT level for the analysis = 6,7.
alphaFBM=1.5; % parameter for 1/f^alphaFBM noise, alphaFBM \in ]0,2[; 
Wreg1='db1'; % First DWPT regularity for the analysis  
Wreg2='db7'; % 2nd DWPT regularity; 'db7','db20'.
NbITER=5; % Number of iterations.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
[axc1, axc2, axc3, Lx] = AsympCorrelationDWPTFBM(alphaFBM,Wlevel1,Wlevel2,Wreg1,Wreg2,NbITER);
%
T=-(Lx-1)/2:1:(Lx-1)/2;  % centering in 9(0,0)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%     PATH 1 (corresponds to path P_{0})          %% 
%%%%%%%     The variance for the limit                  %%
%%%%%%%     Gaussian distribution is the value at 0     %%
%%%%%%%     of the power spectral density of the input  %%
%%%%%%%     random process: \gamma(0).                  %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% R_{0,0} = normalised autocorrelation function of the input random process.
figure
subplot(2,2,1)
plot(T,1./(abs(T)).^alphaFBM,'d:')
hold on
xlabel('m')
title('R_{0,0}[m]');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Autocorrelation function at level "Wlevel1" with regularity "Wreg1".
subplot(2,2,2)
plot(T,axc1(1,:),'d:')
hold on
xlabel('m')
title(['R_{' num2str(Wlevel1) ',n_{{0}}(' num2str(Wlevel1) ')}^{[' num2str(Wreg1) ']}[m]']);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Autocorrelation function at level "Wlevel2" with regularity "Wreg1".
subplot(2,2,3)
plot(T,axc2(1,:),'d:')
hold on
xlabel('m')
title(['R_{' num2str(Wlevel2) ',n_{{0}}(' num2str(Wlevel2) ')}^{[' num2str(Wreg1) ']}[m]']);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Autocorrelation function at level "Wlevel2" with regularity "Wreg2".
subplot(2,2,4)
plot(T,axc3(1,:),'d:')
hold on
xlabel('m')
title(['R_{' num2str(Wlevel2) ',n_{{0}}(' num2str(Wlevel2) ')}^{[' num2str(Wreg2) ']}[m]']);
hold off
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%     PATH 2 (corresponds to path P_{PI/4})       %% 
%%%%%%%     The variance for the limit                  %%
%%%%%%%     Gaussian distribution is the value at PI/4  %%
%%%%%%%     of the power spectral density of the input  %%
%%%%%%%     random process                              %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% R_{0,0} = autocorrelation function of the input random process.
figure
subplot(2,2,1)
plot(T,1./(abs(T)).^alphaFBM,'d:')
hold on
xlabel('m')
title('R_{0,0}[m]');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Autocorrelation function at level "Wlevel1" with regularity "Wreg1".
subplot(2,2,2)
plot(T,axc1(2,:),'d:')
hold on
xlabel('m')
title(['R_{' num2str(Wlevel1) ',n_{{\pi/4}}(' num2str(Wlevel1) ')}^{[' num2str(Wreg1) ']}[m]']);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Autocorrelation function at level "Wlevel2" with regularity "Wreg1".
subplot(2,2,3)
plot(T,axc2(2,:),'d:')
hold on
xlabel('m')
title(['R_{' num2str(Wlevel2) ',n_{{\pi/4}}(' num2str(Wlevel2) ')}^{[' num2str(Wreg1) ']}[m]']);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Autocorrelation function at level "Wlevel2" with regularity "Wreg2".
subplot(2,2,4)
plot(T,axc3(2,:),'d:')
xlabel('m')
title(['R_{' num2str(Wlevel2) ',n_{{\pi/4}}(' num2str(Wlevel2) ')}^{[' num2str(Wreg2) ']}[m]']);
hold off
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%     PATH 3 (corresponds to path P_{PI/2})       %% 
%%%%%%%     The variance for the limit                  %%
%%%%%%%     Gaussian distribution is the value at PI/2  %%
%%%%%%%     of the power spectral density of the input  %%
%%%%%%%     random process                              %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% R_{0,0} = autocorrelation function of the input random process.
figure
subplot(2,2,1)
plot(T,1./(abs(T)).^alphaFBM,'d:')
hold on
xlabel('m')
title('R_{0,0}[m]');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Autocorrelation function at level "Wlevel1" with regularity "Wreg1".
subplot(2,2,2)
plot(T,axc1(3,:),'d:')
hold on
xlabel('m')
title(['R_{' num2str(Wlevel1) ',n_{{\pi/2}}(' num2str(Wlevel1) ')}^{[' num2str(Wreg1) ']}[m]']);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Autocorrelation function at level "Wlevel2" with regularity "Wreg1".
subplot(2,2,3)
plot(T,axc2(3,:),'d:')
hold on
xlabel('m')
title(['R_{' num2str(Wlevel2) ',n_{{\pi/2}}(' num2str(Wlevel2) ')}^{[' num2str(Wreg1) ']}[m]']);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Autocorrelation function at level "Wlevel2" with regularity "Wreg2".
subplot(2,2,4)
plot(T,axc3(3,:),'d:')
xlabel('m')
title(['R_{' num2str(Wlevel2) ',n_{{\pi/2}}(' num2str(Wlevel2) ')}^{[' num2str(Wreg2) ']}[m]']);
hold off
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%     PATH 4 (corresponds to path P_{PI})         %% 
%%%%%%%     The variance for the limit                  %%
%%%%%%%     Gaussian distribution is the value at PI    %%
%%%%%%%     of the power spectral density of the input  %%
%%%%%%%     random process                              %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% R_{0,0} = autocorrelation function of the input random process.
figure
subplot(2,2,1)
plot(T,1./(abs(T)).^alphaFBM,'d:')
hold on
xlabel('m')
title('R_{0,0}[m]');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Autocorrelation function at level "Wlevel1" with regularity "Wreg1".
subplot(2,2,2)
plot(T,axc1(4,:),'d:')
hold on
xlabel('m')
title(['R_{' num2str(Wlevel1) ',n_{{\pi}}(' num2str(Wlevel1) ')}^{[' num2str(Wreg1) ']}[m]']);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Autocorrelation function at level "Wlevel2" with regularity "Wreg1".
subplot(2,2,3)
plot(T,axc2(4,:),'d:')
hold on
xlabel('m')
title(['R_{' num2str(Wlevel2) ',n_{{\pi}}(' num2str(Wlevel2) ')}^{[' num2str(Wreg1) ']}[m]']);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Autocorrelation function at level "Wlevel2" with regularity "Wreg2".
subplot(2,2,4)
plot(T,axc3(4,:),'d:')
xlabel('m')
title(['R_{' num2str(Wlevel2) ',n_{{\pi}}(' num2str(Wlevel2) ')}^{[' num2str(Wreg2) ']}[m]']);
hold off
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright: am.atto@telecom-bretagne.eu
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%