%%        INPUTS
% muAR:    Parameter for the Autoregressive AR(1) filter (used to colour
%                        the white GGD random process), muAR \in ]0, 1[.
% Wlevel: Wavelet Packet Analysis at level ``Wlevel''.
% Wreg:   Wavelet Packet filtering with regularity (order) ``Wreg''.
% NbITER:  Number of iterations.
% pas:     Number of bins per output histogram. 
% 
%%        OUTPUTS

%%
clear all
close all
clc
Ndata=2^20;
alpha=1;
NbITER=2;
Wlevel=9;
Wreg1='db7';
Wreg2='db45';
Wreg3='sym8';
Wreg4='sym30';
Wreg5='coif5';
Wreg6='dmey';
%%
% AR filter
%A=[1 -0.05 -0.01 -0.15 -0.1 -0.2];
%B=sum(A);
%%
% Frequency 2^Wlevel points
p=0:1:2^Wlevel-1;
n=int2gray(p);
fin=2^Wlevel;
FW_psd=zeros(NbITER,fin);
WP_psd1=zeros(NbITER,fin);
WP_psd2=zeros(NbITER,fin);
WP_psd3=zeros(NbITER,fin);
WP_psd4=zeros(NbITER,fin);
WP_psd5=zeros(NbITER,fin);
WP_psd6=zeros(NbITER,fin);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
h = waitbar(0,'Please wait, computing ...');
for ITER=1:NbITER
    %======> White random process
    %W = randn(1,Ndata);
    % Correlated random process
    %sig = filter(B,A,W);
    %
    sig=powernoise(alpha,Ndata);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Fourier-Welch periodogram method
    [sp,ci]=spectrum(sig,2^(Wlevel+1)-1);
    FW_psd(ITER,:)=sp(:,1);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%  Wavelet Packet Spectrum at Wlevel with Wreg
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    WP_psd1(ITER,:)=WPspectrum(sig,Wlevel,Wreg1);
    WP_psd2(ITER,:)=WPspectrum(sig,Wlevel,Wreg2);
    WP_psd3(ITER,:)=WPspectrum(sig,Wlevel,Wreg3);
    WP_psd4(ITER,:)=WPspectrum(sig,Wlevel,Wreg4);
    WP_psd5(ITER,:)=WPspectrum(sig,Wlevel,Wreg5);
    WP_psd6(ITER,:)=WPspectrum(sig,Wlevel,Wreg6);
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    waitbar(ITER/NbITER,h)
end
close(h)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ncount=0;
a_Sfw=zeros(NbITER,1); 
a_Swp1=zeros(NbITER,1); a_Swp2=zeros(NbITER,1); a_Swp3=zeros(NbITER,1); 
a_Swp4=zeros(NbITER,1); a_Swp5=zeros(NbITER,1); a_Swp6=zeros(NbITER,1); 
for k=2:2^(Wlevel)
    for m=k+1:2^(Wlevel) 
        a_Sfw=a_Sfw+log(FW_psd(:,m)./FW_psd(:,k))/log(m/k); 
        a_Swp1=a_Swp1+log(WP_psd1(:,m)./WP_psd1(:,k))/log(m/k); 
        a_Swp2=a_Swp2+log(WP_psd2(:,m)./WP_psd2(:,k))/log(m/k); 
        a_Swp3=a_Swp3+log(WP_psd3(:,m)./WP_psd3(:,k))/log(m/k); 
        a_Swp4=a_Swp4+log(WP_psd4(:,m)./WP_psd4(:,k))/log(m/k); 
        a_Swp5=a_Swp5+log(WP_psd5(:,m)./WP_psd5(:,k))/log(m/k); 
        a_Swp6=a_Swp6+log(WP_psd6(:,m)./WP_psd6(:,k))/log(m/k); 
        ncount=ncount+1; 
    end; 
end; 
a_Sfw=-a_Sfw./ncount;
a_Swp1=-a_Swp1./ncount; a_Swp2=-a_Swp2./ncount; a_Swp3=-a_Swp3./ncount; 
a_Swp4=-a_Swp4./ncount; a_Swp5=-a_Swp5./ncount; a_Swp6=-a_Swp6./ncount;
%%
a_0=sum(a_Sfw)/NbITER;
a_1=sum(a_Swp1)/NbITER;
a_2=sum(a_Swp2)/NbITER;
a_3=sum(a_Swp3)/NbITER;
a_4=sum(a_Swp4)/NbITER;
a_5=sum(a_Swp5)/NbITER;
a_6=sum(a_Swp6)/NbITER;
a=[a_0 a_1 a_2 a_3 a_4 a_5 a_6];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Plot Spectrum: Wavelet method versus Fourier-Welch method
debut=2;
xpas=1;
fin2=min(32,fin);
figure
hold on
plot(ci(debut:xpas:fin2),WP_psd1(1,debut:xpas:fin2),'d-')
plot(ci(debut:xpas:fin2),FW_psd(1,debut:xpas:fin2),'ro-')
hold off
title('Fourier-Welch Versus Wavelet Packet Spectrum Estimation')
legend('Daub[7]' , 'Welch')


txt01=['Fourier-Welch Versus Wavelet Packet (WP)'];
txt02=['Based 1/f^\alpha Parameter Estimation'];
txt03=['True(\alpha)  -------> ',num2str(alpha)];
text1=['F-Welch     ---------> ',num2str(a(1))];
text2=['WP-Daub[7]  ---------> ',num2str(a(2))];
text3=['WP-Daub[45] ---------> ',num2str(a(3))];
text4=['WP-Sym[8]   ---------> ',num2str(a(4))];
text5=['WP-Sym[30]  ---------> ',num2str(a(5))];
text6=['WP-Coif[5]  ---------> ',num2str(a(6))];
text7=['WP-Meyer    ---------> ',num2str(a(7))];
text=char(txt01,txt02,txt03,text1,text2,text3,text4,text5,text6,text7)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright: am.atto@telecom-bretagne.eu
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%